@@ -3,10 +3,8 @@
 use strict;
 use warnings;
 package Alien::GPG::Error;
-BEGIN {
-  $Alien::GPG::Error::AUTHORITY = 'cpan:AJGB';
-}
-$Alien::GPG::Error::VERSION = '1.17.0';
+our $AUTHORITY = 'cpan:AJGB';
+$Alien::GPG::Error::VERSION = '1.21.0';
 use parent 'Alien::Base';
 
 1;
@@ -23,7 +21,7 @@ Alien::GPG::Error - Install and make available libgpg-error
 
 =head1 VERSION
 
-version 1.17.0
+version 1.21.0
 
 =head1 SYNOPSIS
 
@@ -34,7 +32,7 @@ version 1.17.0
 
 =head1 DESCRIPTION
 
-Alien::GPG::Error installs the C library C<libgpg-error>.
+Alien::GPG::Error installs the C library C<libgpg-error> v1.21.
 
 =head1 SEE ALSO
 
@@ -50,7 +48,7 @@ Alex J. G. Burzyński <ajgb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Alex J. G. Burzyński <ajgb@cpan.org>.
+This software is copyright (c) 2016 by Alex J. G. Burzyński <ajgb@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
